@@ -283,7 +283,8 @@ typedef enum
   /* 15 was removed (TASK_STATUS_STOP_REQUESTED_GIVEUP). */
   TASK_STATUS_DELETE_WAITING = 16,
   TASK_STATUS_DELETE_ULTIMATE_WAITING = 17,
-  TASK_STATUS_QUEUED = 18
+  TASK_STATUS_QUEUED = 18,
+  TASK_STATUS_PROCESSING = 19,
 } task_status_t;
 
 /**
@@ -406,6 +407,12 @@ type_is_scap (const char*);
 int
 delete_resource (const char *, const char *, int);
 
+int
+resource_id_deprecated (const char *, const char *);
+
+void
+set_resource_id_deprecated (const char *, const char *, gboolean);
+
 
 /* Events and Alerts. */
 
@@ -1180,7 +1187,7 @@ result_detection_reference (result_t, report_t, const char *, const char *,
  */
 #define MIN_QOD_DEFAULT 70
 
-/** 
+/**
  * @brief Default size to limit note and override text to in reports.
  */
 #define EXCERPT_SIZE_DEFAULT 300
@@ -1520,6 +1527,78 @@ result_iterator_cert_bunds (iterator_t*);
 gchar **
 result_iterator_dfn_certs (iterator_t*);
 
+const char *
+result_iterator_delta_state (iterator_t*);
+
+const char *
+result_iterator_delta_description (iterator_t*);
+
+const char *
+result_iterator_delta_severity (iterator_t*);
+
+double
+result_iterator_delta_severity_double (iterator_t*);
+
+const char*
+result_iterator_delta_level (iterator_t*);
+
+const char *
+result_iterator_delta_original_severity (iterator_t*);
+
+double
+result_iterator_delta_original_severity_double (iterator_t*);
+
+const char*
+result_iterator_delta_original_level (iterator_t*);
+
+const char *
+result_iterator_delta_qod (iterator_t*);
+
+const char *
+result_iterator_delta_uuid (iterator_t*);
+
+const char *
+result_iterator_delta_qod_type (iterator_t*);
+
+const char *
+result_iterator_delta_creation_time (iterator_t*);
+
+const char *
+result_iterator_delta_modification_time (iterator_t*);
+
+task_t
+result_iterator_delta_task (iterator_t*);
+
+report_t
+result_iterator_delta_report (iterator_t*);
+
+const char *
+result_iterator_delta_owner_name (iterator_t*);
+
+const char *
+result_iterator_delta_path (iterator_t*);
+
+const char *
+result_iterator_delta_host_asset_id (iterator_t*);
+
+const char *
+result_iterator_delta_nvt_version (iterator_t*);
+
+result_t
+result_iterator_delta_result (iterator_t*);
+
+int
+result_iterator_delta_may_have_notes (iterator_t*);
+
+int
+result_iterator_delta_may_have_overrides (iterator_t*);
+
+int
+result_iterator_delta_may_have_tickets (iterator_t*);
+
+const char *
+result_iterator_delta_hostname (iterator_t*);
+
 int
 cleanup_result_nvts ();
 
@@ -1997,7 +2076,7 @@ void
 xml_append_nvt_refs (GString *, const char *, int *);
 
 gchar*
-get_nvt_xml (iterator_t*, int, int, int, const char*, config_t, int, int);
+get_nvt_xml (iterator_t*, int, int, int, const char*, config_t, int, int, int, int);
 
 char*
 task_preference_value (task_t, const char *);
