@@ -1,4 +1,4 @@
-/* Copyright (C) 2019-2022 Greenbone Networks GmbH
+/* Copyright (C) 2019-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -168,10 +168,6 @@ config_timeout_iterator_nvt_name (iterator_t *);
 const char*
 config_timeout_iterator_value (iterator_t *);
 
-void
-update_config_preference (const char *, const char *, const char *,
-                          const char *, gboolean);
-
 gboolean
 configs_feed_dir_exists ();
 
