@@ -331,7 +331,7 @@ batch_start (int max)
 /**
  * @brief Check an SQL batch.
  *
- * @para[in]  b  Batch.
+ * @param[in]  b  Batch.
  *
  * @return 1 init b->str, 0 continue as normal.
  */
@@ -365,7 +365,7 @@ batch_check (batch_t *b)
 /**
  * @brief End and free an SQL batch.
  *
- * @para[in]  b  Batch.
+ * @param[in]  b  Batch.
  */
 void
 batch_end (batch_t *b)
@@ -414,7 +414,7 @@ insert_vt_refs (const nvti_t *nvti, int rebuild, batch_t *batch)
                                 rebuild ? "_rebuild" : "");
       else
         comma = 1;
-                               
+
       g_string_append_printf (batch->sql,
                               // Newline in case it gets logged.
                               "%s\n ('%s', '%s', '%s', '%s')",
@@ -1210,7 +1210,7 @@ char *
 nvt_default_timeout (const char* oid)
 {
   return sql_string ("SELECT value FROM nvt_preferences"
-                     " WHERE name = '%s:0:entry:Timeout'",
+                     " WHERE name = '%s:0:entry:timeout'",
                      oid);
 }
 
@@ -1594,7 +1594,7 @@ nvti_from_vt (element_t vt)
                 = element_child (severity, "origin");
               severity_date
                 = element_child (severity, "date");
-              
+
               if (severity_date) {
                 gchar *text;
 
@@ -2016,7 +2016,7 @@ init_nvt_severity_iterator (iterator_t* iterator, const char *oid)
  * @brief Gets the type from an NVT severity iterator.
  *
  * @param[in]  iterator  Iterator.
- * 
+ *
  * @return The type of the severity.
  */
 DEF_ACCESS (nvt_severity_iterator_type, 0)
@@ -2025,7 +2025,7 @@ DEF_ACCESS (nvt_severity_iterator_type, 0)
  * @brief Gets the origin from an NVT severity iterator.
  *
  * @param[in]  iterator  Iterator.
- * 
+ *
  * @return The origin of the severity.
  */
 DEF_ACCESS (nvt_severity_iterator_origin, 1);
@@ -2034,7 +2034,7 @@ DEF_ACCESS (nvt_severity_iterator_origin, 1);
  * @brief Gets the date from an NVT severity iterator.
  *
  * @param[in]  iterator  Iterator.
- * 
+ *
  * @return The date of the severity in ISO time format.
  */
 DEF_ACCESS (nvt_severity_iterator_date, 2);
@@ -2043,7 +2043,7 @@ DEF_ACCESS (nvt_severity_iterator_date, 2);
  * @brief Gets the score from an NVT severity iterator.
  *
  * @param[in]  iterator  Iterator.
- * 
+ *
  * @return The score of the severity.
  */
 double
@@ -2056,7 +2056,7 @@ nvt_severity_iterator_score (iterator_t *iterator)
  * @brief Gets the value from an NVT severity iterator.
  *
  * @param[in]  iterator  Iterator.
- * 
+ *
  * @return The value of the severity in ISO time format.
  */
 DEF_ACCESS (nvt_severity_iterator_value, 4);
@@ -2390,7 +2390,7 @@ manage_sync_nvts (int (*fork_update_nvt_cache) ())
  * @param[in]  update  0 rebuild, else update.
  *
  * @return 0 success, -1 error, -1 no osp update socket, -2 could not connect
- *         to osp update socket -3 failed to get scanner version
+ *         to osp update socket, -3 failed to get scanner version
  */
 int
 update_or_rebuild_nvts (int update)
@@ -2456,8 +2456,9 @@ update_or_rebuild_nvts (int update)
  * @param[in]  database    Location of manage database.
  *
  * @return 0 success, 1 VT integrity check failed, -1 error,
- *         -2 database is wrong version,
- *         -3 database needs to be initialised from server, -5 sync active.
+ *         -2 database is too old,
+ *         -3 database needs to be initialised from server,
+ *         -5 database is too new, -6 sync active.
  */
 int
 manage_rebuild (GSList *log_config, const db_conn_info_t *database)
@@ -2471,7 +2472,7 @@ manage_rebuild (GSList *log_config, const db_conn_info_t *database)
     {
       case 1:
         printf ("A feed sync is already running.\n");
-        return -5;
+        return -6;
       case -1:
         printf ("Error getting sync lock.\n");
         return -1;
@@ -2525,8 +2526,9 @@ manage_rebuild (GSList *log_config, const db_conn_info_t *database)
  * @param[in]  log_config  Log configuration.
  * @param[in]  database    Location of manage database.
  *
- * @return 0 success, -1 error, -2 database is wrong version,
- *         -3 database needs to be initialised from server, -5 sync active.
+ * @return 0 success, -1 error, -2 database is too old,
+ *         -3 database needs to be initialised from server,
+ *         -5 database is too new, -6 sync active.
  */
 int
 manage_dump_vt_verification (GSList *log_config,
@@ -2540,7 +2542,7 @@ manage_dump_vt_verification (GSList *log_config,
     {
       case 1:
         printf ("A feed sync is already running.\n");
-        return -5;
+        return -6;
       case -1:
         printf ("Error getting sync lock.\n");
         return -1;
